@@ -5,3 +5,6 @@ from Arbie.Actions.action_tree import ActionTree  # noqa: F401
 from Arbie.Actions.arbitrage import Arbitrage  # noqa:F401
 from Arbie.Actions.path_finder import PathFinder  # noqa: F401
 from Arbie.Actions.pool_finder import PoolFinder  # noqa: F401
+from Arbie.Actions.pool_updater import PoolUpdater  # noqa: F401
+from Arbie.Actions.redis_state import RedisState  # noqa: F401
+from Arbie.Actions.trader import Trader  # noqa: F401
