@@ -13,6 +13,16 @@ class BigNumber(object):
             return self.value == other.value and self.exp == other.exp
         return self.value == other
 
+    def __lt__(self, other):
+        if isinstance(other, BigNumber):
+            return self.value < other.value
+        return self.value < other
+
+    def __gt__(self, other):
+        if isinstance(other, BigNumber):
+            return self.value > other.value
+        return self.value > other
+
     def __truediv__(self, other):
         return self.to_number() / other.to_number()
 
